@@ -18,14 +18,15 @@ class FileFilter(Filter):
         self._exclude_literal = []
         self._extention = []
         self._ex_extention = []
+        self._start_with = []
+        self._end_with = []
 
     def __call__(self, target: str) -> bool:
         if isinstance(target, Directory):
             return True
         if not isinstance(target, str):
             raise TypeError(
-                "The argument 'target' type must be 'str', "
-                + f" but detect '{target.__class__.__name__}'",
+                "The argument 'target' type must be 'str', " + f" but detect '{target.__class__.__name__}'",
             )
 
         target = os.sep.join(re.split(r"[\\/]", target))
@@ -59,10 +60,57 @@ class FileFilter(Filter):
                 if literal in os.path.basename(target):
                     return False
 
+        if self._start_with:
+            exist = False
+            for literal in self._start_with:
+                if os.path.basename(target).startswith(literal):
+                    exist = True
+                    break
+            if not exist:
+                return False
+
+        if self._end_with:
+            exist = False
+            for literal in self._end_with:
+                ext = os.path.splitext(target)[-1]
+                if os.path.basename(target).endswith(literal + ext):
+                    exist = True
+                    break
+            if not exist:
+                return False
+
         return True
 
+    def chake_form_args(self, literal: List[str] | str) -> List[str]:
+        """Check the type of the argument.
+
+        Args:
+            literal (List[str] | str): The argument to check.
+
+        Raises:
+            TypeError: If the argument is not a string or a list of strings.
+        """
+
+        if isinstance(literal, str):
+            return [literal]
+        elif not isinstance(literal, list):
+            raise TypeError(
+                "The argument 'literal' type must be 'str' or 'List[str]', "
+                + f"but detect '{literal.__class__.__name__}'",
+            )
+        elif literal == []:
+            return literal
+        elif not isinstance(literal[0], str):
+            raise TypeError(
+                "The argument 'literal' type must be 'str' or 'List[str]', "
+                + f"but detect '{literal.__class__.__name__}'",
+            )
+        else:
+            return literal
+
     def contained(self, literal: List[str] | str) -> FileFilter:
-        """set criteria, get file path which contain `literal`.
+        """set criteria, get file name which contain `literal`.
+        The criteria behaves like the logical sum.
 
         Args:
             literal (List[str] | str): Criteria for filtering files
@@ -72,27 +120,15 @@ class FileFilter(Filter):
             FileFilter: Callable instance that filters by specified criteria.
         """
 
-        if isinstance(literal, str):
-            literal = [literal]
-        elif not isinstance(literal, list):
-            raise TypeError(
-                "The argument 'literal' type must be 'str' or 'List[str]', "
-                + f"but detect '{literal.__class__.__name__}'",
-            )
-        elif literal == []:
-            return self
-        elif not isinstance(literal[0], str):
-            raise TypeError(
-                "The argument 'literal' type must be 'str' or 'List[str]', "
-                + f"but detect '{literal.__class__.__name__}'",
-            )
+        literal = self.chake_form_args(literal)
 
         self._contain_literal += literal
 
         return self
 
     def uncontained(self, literal: List[str] | str) -> FileFilter:
-        """set criteria, get file path which dose not contain `literal`.
+        """set criteria, get file name which dose not contain `literal`.
+        This criteria behaves like the negative logical sum.
 
         Args:
             literal (List[str] | str): Criteria for filtering files
@@ -102,20 +138,7 @@ class FileFilter(Filter):
             FileFilter: Callable instance that filters by specified criteria.
         """
 
-        if isinstance(literal, str):
-            literal = [literal]
-        elif not isinstance(literal, list):
-            raise TypeError(
-                "The argument 'literal' type must be 'str' or 'List[str]', "
-                + f"but detect '{literal.__class__.__name__}'",
-            )
-        elif literal == []:
-            return self
-        elif not isinstance(literal[0], str):
-            raise TypeError(
-                "The argument 'literal' type must be 'str' or 'List[str]', "
-                + f"but detect '{literal.__class__.__name__}'",
-            )
+        literal = self.chake_form_args(literal)
 
         self._exclude_literal += literal
 
@@ -123,6 +146,7 @@ class FileFilter(Filter):
 
     def include_extention(self, extention: List[str] | str) -> FileFilter:
         """Specify the including file extension.
+        The criteria behaves like the logical sum.
 
         Args:
             extention (List[str] | str): Criteria for filtering files
@@ -132,20 +156,7 @@ class FileFilter(Filter):
             FileFilter: Callable instance that filters by specified criteria.
         """
 
-        if isinstance(extention, str):
-            extention = [extention]
-        elif not isinstance(extention, list):
-            raise TypeError(
-                "The argument 'extention' type must be 'str' or 'List[str]', "
-                + f"but detect '{extention.__class__.__name__}'",
-            )
-        elif extention == []:
-            return self
-        elif not isinstance(extention[0], str):
-            raise TypeError(
-                "The argument 'extention' type must be 'str' or 'List[str]', "
-                + f"but detect '{extention.__class__.__name__}'",
-            )
+        extention = self.chake_form_args(extention)
 
         self._extention += extention
 
@@ -153,6 +164,7 @@ class FileFilter(Filter):
 
     def exclude_extention(self, extention: List[str] | str) -> FileFilter:
         """Specify the excluding file extension.
+        This criteria behaves like the negative logical sum.
 
         Args:
             extention (List[str] | str): Criteria for filtering files
@@ -162,25 +174,48 @@ class FileFilter(Filter):
             FileFilter: Callable instance that filters by specified criteria.
         """
 
-        if isinstance(extention, str):
-            extention = [extention]
-        elif not isinstance(extention, list):
-            raise TypeError(
-                "The argument 'extention' type must be 'str' or 'List[str]', "
-                + f"but detect '{extention.__class__.__name__}'",
-            )
-        elif extention == []:
-            return self
-        elif not isinstance(extention[0], str):
-            raise TypeError(
-                "The argument 'extention' type must be 'str' or 'List[str]', "
-                + f"but detect '{extention.__class__.__name__}'",
-            )
+        extention = self.chake_form_args(extention)
 
         self._ex_extention += extention
 
         return self
 
+    def start_with(self, literal: List[str] | str) -> FileFilter:
+        """set criteria, get file name which start with `literal`.
+        The criteria behaves like the logical sum.
+
+        Args:
+            literal (List[str] | str): Criteria for filtering files
+            that start with `literal` in the filename.
+
+        Returns:
+            FileFilter: Callable instance that filters by specified criteria.
+        """
+
+        literal = self.chake_form_args(literal)
+
+        self._start_with += literal
+
+        return self
+
+    def end_with(self, literal: List[str] | str) -> FileFilter:
+        """set criteria, get file name which end with `literal`.
+        This criteria behaves like the negative logical sum.
+
+        Args:
+            literal (List[str] | str): Criteria for filtering files
+            that end with `literal` in the filename.
+
+        Returns:
+            FileFilter: Callable instance that filters by specified criteria.
+        """
+
+        literal = self.chake_form_args(literal)
+
+        self._end_with += literal
+
+        return self
+
     def __str__(self) -> str:
         cond_str = "FileFilter\n"
         for key, value in vars(self).items():
@@ -204,20 +239,19 @@ class DircFilter(Filter):
         if isinstance(target, Directory):
             target = target.path
         elif not isinstance(target, str):
-            raise TypeError(
-                f"The argument 'target' type must be 'str', but detect '{target.__class__.__name__}'"
-            )
+            raise TypeError(f"The argument 'target' type must be 'str', but detect '{target.__class__.__name__}'")
         if isinstance(target, str):
             if os.path.isfile(target):
                 target = os.path.dirname(target)
+        if os.path.isfile(target):
+            target = os.path.dirname(target)
 
         target = os.sep.join(re.split(r"[\\/]", target))
 
         if self._only_terminal_dirc:
-            dirs_path = os.path.dirname(target)
-            mems = os.listdir(dirs_path)
+            mems = os.listdir(target)
             for mem in mems:
-                if os.path.isdir(os.path.join(dirs_path, mem)):
+                if os.path.isdir(os.path.join(target, mem)):
                     return False
 
         if self._contain_dirc:
